#include "TabMod.h"
#include "System.h"
#include "Settings.h"
#include "FilePaths.h"

DialogSelectMod::DialogSelectMod(QWidget *parent) : QDialog(parent)
{
	QVBoxLayout *mainLayout = new QVBoxLayout();
	QHBoxLayout *lowerLayout = new QHBoxLayout();

	QPushButton *selectButton = new QPushButton("Select");
	QPushButton *cancelButton = new QPushButton("Cancel");

	QStringListModel *model = new QStringListModel();
	view = new QListView();

	mods = QDir(FilePaths::getGameDir()).entryList(QDir::AllDirs, QDir::Name);
	mods.removeAll(".");
	mods.removeAll("..");
	mods.removeAll("data");

	if (mods.isEmpty()) {
		QLabel *noModsLabel = new QLabel("You don't have any mods.");
		mainLayout -> addWidget(noModsLabel);
		goto end;
	}

	model -> setStringList(mods);
	view -> setEditTriggers(QAbstractItemView::NoEditTriggers);
	view -> setModel(model);
	mainLayout -> addWidget(view);

	connect(view, SIGNAL(activated(const QModelIndex&)), this, SLOT(accept()));
	connect(view, SIGNAL(doubleClicked(const QModelIndex&)), this, SLOT(accept()));

end:
	connect(selectButton, SIGNAL(clicked()), this, SLOT(accept()));
	connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
	lowerLayout -> addWidget(selectButton);
	lowerLayout -> addWidget(cancelButton);

	mainLayout -> addLayout(lowerLayout);

	setLayout(mainLayout);
}

QString DialogSelectMod::select()
{
	if (exec() == QDialog::Rejected)
		return QString();
	return view -> currentIndex().data().toString();
}

TabMod::TabMod(QWidget *parent) : QWidget(parent)
{
	QVBoxLayout *mainLayout = new QVBoxLayout();
	QGroupBox *groupBox = new QGroupBox();

	QVBoxLayout *inGroupLayout = new QVBoxLayout();

	QHBoxLayout *modLayout = new QHBoxLayout();
	QPushButton *selectModButton = new QPushButton("Select MOD");
	QPushButton *noModButton = new QPushButton("No MOD");
	modNameLabel = new QLabel();

	connect(selectModButton, SIGNAL(clicked()), this, SLOT(selectModButtonClicked()));
	connect(noModButton, SIGNAL(clicked()), this, SLOT(noModButtonClicked()));

	QGroupBox *detailsBox = new QGroupBox("MOD Details");

	QFont smallerFont;
	smallerFont.setPointSize(8);
	QVBoxLayout *detailsLayout = new QVBoxLayout();
	modLabel = new QLabel();
	modDescription = new QTextEdit();
	modDescription -> setFont(smallerFont);
	QHBoxLayout *buttonsLayout = new QHBoxLayout();
	QPushButton *websiteButton = new QPushButton("Website");
	QPushButton *forumButton = new QPushButton("Forum");

	connect(websiteButton, SIGNAL(clicked()), this, SLOT(websiteButtonClicked()));
	connect(forumButton, SIGNAL(clicked()), this, SLOT(forumButtonClicked()));

	modNameLabel -> setFrameStyle(QFrame::StyledPanel);
	modNameLabel -> setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
	modLayout -> addWidget(selectModButton);
	modLayout -> addWidget(noModButton);
	modLayout -> addWidget(modNameLabel);

	buttonsLayout -> addWidget(websiteButton);
	buttonsLayout -> addWidget(forumButton);

	modLabel -> setFixedSize(255, 112);
	modLabel -> setFrameStyle(QFrame::StyledPanel);
	modDescription -> setReadOnly(true);
	//modDescription -> setFixedWidth(255);
	detailsLayout -> addWidget(modLabel);
	detailsLayout -> addWidget(modDescription);
	detailsLayout -> addLayout(buttonsLayout);
	detailsLayout -> setAlignment(modLabel, Qt::AlignHCenter);
	//detailsLayout -> setAlignment(modDescription, Qt::AlignHCenter);

	detailsBox -> setLayout(detailsLayout);

	inGroupLayout -> addLayout(modLayout);
	inGroupLayout -> addWidget(detailsBox);

	groupBox -> setLayout(inGroupLayout);

	mainLayout -> addWidget(groupBox);
	mainLayout -> setContentsMargins(0, 0, 0, 0);
	setLayout(mainLayout);
}

void TabMod::updateUI()
{
	modNameLabel -> setText(SETTINGS.modName);
	modLabel -> setPixmap(QPixmap(FilePaths::getModPixmap(SETTINGS.modName,SETTINGS.modImage)));
	modDescription -> setText(SETTINGS.modInfo);
}

void TabMod::selectModButtonClicked()
{
	DialogSelectMod dialog(this);
	QString mod = dialog.select();
	if (! mod.isEmpty()) {
		SETTINGS.setModName(mod);
		emit setUpdateUI();
	}
}

void TabMod::noModButtonClicked()
{
	SETTINGS.setModName("");
	emit setUpdateUI();
}

void TabMod::websiteButtonClicked()
{
	System::runBrowser(SETTINGS.modWebsite);
}

void TabMod::forumButtonClicked()
{
	System::runBrowser(SETTINGS.modForum);
}
