#include <unistd.h>
#include <errno.h>
#include <stdlib.h>
#include <time.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <sys/wait.h>

#include "System.h"

#define BROWSERCMD	"browser"

bool System::run(const QString &exec, const QStringList &params, bool waitForEnd)
{
	if (exec.isEmpty())
		return false;

	if (QFileInfo(exec).isAbsolute()) {
		if (! QFileInfo(exec).exists())
			return false;
		if (! QFileInfo(exec).isExecutable())
			return false;
	}

	char *argv[params.size()+2];
	int i, ret=0;

	argv[0] = strdup(exec.toAscii().data());
	for (i = 0; i < params.size(); i++)
		argv[i+1] = strdup(params.at(i).toAscii().data());
	argv[i+1] = NULL;

	pid_t pid = fork();
	if (pid == -1)
		return false;
	if (pid == 0)
		ret = execvp(argv[0], argv);
	if (ret == -1)
		exit(1);
	if (waitForEnd)
		waitpid(pid, NULL, 0);

	for (i = 0; argv[i] != NULL; i++)
		delete argv[i];

	return true;
}

bool System::runBrowser(const QString &url)
{
	if (url.isEmpty())
		return false;

	QString exec = BROWSERCMD;
	QStringList params;
	params.append(url);
	return System::run(exec, params);
}

int System::mSleep(int msec)
{
	return usleep(msec * 1000);
}

QSize System::getSize()
{
	return QSize(350, 500);
}
